@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Hash;
-$List::Objects::WithUtils::Role::Hash::VERSION = '2.028002';
+$List::Objects::WithUtils::Role::Hash::VERSION = '2.028003';
 use strictures 2;
 
 use Module::Runtime ();
@@ -71,12 +71,9 @@ sub exists  { CORE::exists  $_[0]->{ $_[1] } }
 sub is_empty { ! keys %{ $_[0] } }
 
 sub get {
-  if (@_ > 2) {
-    return blessed_or_pkg($_[0])->array_type->new(
-      @{ $_[0] }{ @_[1 .. $#_] }
-    )
-  }
-  $_[0]->{ $_[1] }
+  @_ > 2 ? 
+    blessed_or_pkg($_[0])->array_type->new( @{ $_[0] }{ @_[1 .. $#_] } )
+    : $_[0]->{ $_[1] }
 }
 
 sub get_or_else {
